==> haskell-html-conduit-1.3.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-BpVoUBjAFZ8C1oVlfWR1cM
key: html-conduit-1.3.1-BpVoUBjAFZ8C1oVlfWR1cM
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: 4a6bf35accdc106ab8c5e6d2d43be658
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-BpVoUBjAFZ8C1oVlfWR1cM
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG=4b15a73ad6920f20ed76816962e99c5e
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT=49651e9ab9985fbad79d2cfea10c977e
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-conduit-1.3.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-html-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: html-conduit
version: 1.3.1
id: html-conduit-1.3.1-AbvCnCuf7Hx1AKeBW1LFAa
key: html-conduit-1.3.1-AbvCnCuf7Hx1AKeBW1LFAa
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/xml
synopsis: Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.
category: Web, Text, Conduit
abi: f013730b90f645dc5ca790574faffffb
exposed: True
exposed-modules:
    Text.HTML.DOM
hidden-modules: Text.HTML.TagStream
import-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/html-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/html-conduit-1.3.1
hs-libraries: HShtml-conduit-1.3.1-AbvCnCuf7Hx1AKeBW1LFAa
depends:
    base-4.11.1.0 transformers-0.5.5.0 bytestring-0.10.8.2
    containers-0.5.11.0 text-1.2.3.0
    resourcet-1.2.1-FuawklxGVUZGYJAiOqZc2P
    conduit-1.3.0.3-9CADFiQfBeM8QSPndyUfSD
    xml-conduit-1.8.0-49YHisOHzilDWbhwdugIM4
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    conduit-extra-1.3.0-DujJGjlOTW25Ak3n0YiISA
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             resourcet-1.2.1-FuawklxGVUZGYJAiOqZc2P=bbe5d0b69bce47d466850fbe63de03c7
             conduit-1.3.0.3-9CADFiQfBeM8QSPndyUfSD=4bca304bc332551afda8fa1e909cdcf2
             xml-conduit-1.8.0-49YHisOHzilDWbhwdugIM4=a2bc85573439dec838b738a9e32cd6cb
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             conduit-extra-1.3.0-DujJGjlOTW25Ak3n0YiISA=b47faefb692629bbcc83b647a3a78985
haddock-interfaces: /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock
haddock-html: /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
